# seek

Command line searching for incredibly lazy people.

Seek is a sister to [howdoi](https://github.com/gleitz/howdoi/) and [Glance](https://github.com/Miserlou/glance/).

## Installation

    pip install seek -g

(Doesn't actually work yet.)

## Examples

~/ $ seek wisdom

Wisdom (sophia) is the ability to think and act using knowledge, experience, understanding, common sense, and insight.[1] Wisdom has been regarded as one of four cardinal virtues; and as a virtue, it is a habit or disposition to perform the action with the highest degree of adequacy under any given circumstance. This implies a possession of knowledge or the seeking thereof in order to apply it to the given circumstance. This involves an understanding of people, things, events, situations, and the willingness as well as the ability to apply perception, judgement, and action in keeping with the understanding of what is the optimal course of action. It often requires control of one's emotional reactions (the "passions") so that the universal principle of reason prevails to determine one's action. In short, wisdom is a disposition to find the truth coupled with an optimum judgement as to what actions should be taken in order to deliver the correct outcome.

## Usage

There are a few optional arguments.

    -g 800 --glance 800     Glance mode, 800 WPM (default 500).
    -p --plain              Plaintext mode.
    -p 3 --pos3             Search result position '3' (default 1).

## Features:

* [Glance](http://glance.wtf) mode!
* Diffbot article extraction
* Searches DuckDuckGo

## TODO:

All of the things currently listed as features.

BSD 3-clause, 2014-2015.
